package de.mdelab.expressiondialogs;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.ui.provider.AdapterFactoryContentProvider;
import org.eclipse.emf.edit.ui.provider.AdapterFactoryLabelProvider;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerFilter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;

import de.mdelab.mlcallactions.CallAction;
import de.mdelab.mlcallactions.CallActionExpression;
import de.mdelab.mlexpressions.MLStringExpression;
import de.mdelab.mlexpressions.util.MlExpressionsUtils;
import de.mdelab.mlsdm.Activity;
import de.mdelab.mlsdm.ActivityParameter;
import de.mdelab.mlsdm.ActivityParameterDirectionEnum;
import de.mdelab.mlsdm.OutputParameterValue;
import de.mdelab.mlsdm.diagram.part.MlsdmDiagramEditorPlugin;
import de.mdelab.mlstorypatterns.AttributeAssignment;
import de.mdelab.mlstorypatterns.StoryPatternObject;

public class MlsdmEditOutParameterExpressionDialogNew2 extends MlsdmEditExpressionDialog {

	private Activity	activity;

	public MlsdmEditOutParameterExpressionDialogNew2(Shell parent) {
		super(parent);
		/*
		 * Add a default source viewer for all expression languages that do not
		 * have one.
		 */
		for (String expressionLanguage : MlExpressionsUtils.getAvailableExpressionLanguages())
		{
			if (!this.sourceViewerProviders.containsKey(expressionLanguage))
			{
				this.sourceViewerProviders.put(expressionLanguage, new SourceViewerProvider());
			}
		}

	}
	@Override
	protected void createCallActionHierarchie(){
		this.callActionHierarchie = new TreeViewer(this.upper, SWT.NONE); 

		GridData gridData = new GridData(GridData.FILL, GridData.FILL, true, true, 3, 1);
		gridData.minimumWidth = 500;
		gridData.minimumHeight = 200;
		gridData.widthHint = 500;
		gridData.heightHint = 200;
		this.callActionHierarchie.getTree().setLayoutData(gridData);
		this.callActionHierarchie.setContentProvider(new AdapterFactoryContentProvider(MlsdmDiagramEditorPlugin.getInstance()
				.getItemProvidersAdapterFactory()));
		this.callActionHierarchie.setLabelProvider(new AdapterFactoryLabelProvider.ColorProvider(MlsdmDiagramEditorPlugin
				.getInstance().getItemProvidersAdapterFactory(), this.callActionHierarchie));
		
		if (this.expressionOwner!=null)
		{
			this.callActionHierarchie.setInput(this.expressionOwner);
			ViewerFilter[] viewerFilters = new ViewerFilter[1];
			viewerFilters[0] = new ViewerFilter()
			{

				@Override
				public boolean select(Viewer viewer, Object parentElement, Object element)
				{
					if (MlsdmEditOutParameterExpressionDialogNew2.this.expression instanceof CallActionExpression){
						if (element != MlsdmEditOutParameterExpressionDialogNew2.this.expression){
							EObject container = (EObject) element;
							if (container.eContainer() instanceof CallActionExpression)
							while (container!=null && container != MlsdmEditOutParameterExpressionDialogNew2.this.expression)
								container = container.eContainer();
							if (container == MlsdmEditOutParameterExpressionDialogNew2.this.expression)
								return true;
							return false;
						}
					}
					if (MlsdmEditOutParameterExpressionDialogNew2.this.expression instanceof MLStringExpression){
						if (element instanceof MLStringExpression)
							return true;
					}
					if (MlsdmEditOutParameterExpressionDialogNew2.this.expression instanceof CallActionExpression){
						if (element instanceof CallAction) return true;
						if (element instanceof CallActionExpression) return true;
					}
					if (MlsdmEditOutParameterExpressionDialogNew2.this.expression instanceof AttributeAssignment){
						if (element instanceof AttributeAssignment) return true;
						if (element instanceof MLStringExpression) return true;
					}
					if (MlsdmEditOutParameterExpressionDialogNew2.this.expression instanceof MLStringExpression){
						if (element instanceof OutputParameterValue) return true;
						if (element instanceof MLStringExpression) return true;
					}
					return false;
				}
			};
			this.callActionHierarchie.setFilters(viewerFilters);
		}

		// creating Listener for the TreeItems
		SelectionListener stdTreeItemlistener = createSelectionListener();
		this.callActionHierarchie.getTree().addSelectionListener(stdTreeItemlistener);

	}
	@Override
	protected Map<String, EClassifier> getContextInformation() {
		Map<String, EClassifier> contextInfos = new HashMap<String, EClassifier>();

		if (this.activity != null)
		{
			/*
			 * THIS and parameters
			 */
			if (this.activity/*.getSpecification()*/ != null)
			{
				EClass thisClass = null;//this.activity.getSpecification().getEContainingClass();

				if (thisClass != null)
				{
					contextInfos.put("this", thisClass);
				}

				for (ActivityParameter parameter : this.activity.getParameters())
				{
					if (!parameter.getDirection().getName().equals("IN") && parameter.getName() != null && !"".equals(parameter) && parameter.getType() != null)
					{
						contextInfos.put(parameter.getName(), parameter.getType());
					}
				}
			}
			else
			{
				for (ActivityParameter parameter : this.activity.getParameters())
				{
					if ((parameter.getDirection() == ActivityParameterDirectionEnum.INOUT || parameter.getDirection() == ActivityParameterDirectionEnum.OUT)
							&& parameter.getName() != null && !"".equals(parameter) && parameter.getType() != null)
					{
						contextInfos.put(parameter.getName(), parameter.getType());
					}
				}
			}

			/*
			 * Variables created in story patterns and
			 * VariableDeclarationActions
			 */
			TreeIterator<EObject> it = this.activity.eAllContents();

			while (it.hasNext())
			{
				EObject eObject = it.next();

				if (eObject instanceof StoryPatternObject)
				{
					StoryPatternObject spo = (StoryPatternObject) eObject;

					if (spo.getName() != null && !"".equals(spo.getName()) && spo.getType() != null)
					{
						contextInfos.put(spo.getName(), spo.getType());
					}
				}
			}
		}

		return contextInfos;
	}
	public void setActivity(Activity activity)
	{
		this.activity = activity;
		this.setRootContainer(activity);
	}
	@Override
	protected Control createDialogArea(Composite parent)
	{
		return super.createDialogArea(parent);
	}
}
