package de.mdelab.expressiondialogs;


import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Map;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.core.runtime.Status;
import org.eclipse.draw2d.IFigure;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EOperation;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EParameter;
import org.eclipse.emf.ecore.EcorePackage;
import org.eclipse.emf.query.conditions.booleans.BooleanCondition;
import org.eclipse.emf.query.conditions.eobjects.EObjectCondition;
import org.eclipse.emf.query.conditions.eobjects.EObjectInstanceCondition;
import org.eclipse.emf.query.conditions.eobjects.structuralfeatures.EObjectAttributeValueCondition;
import org.eclipse.emf.query.conditions.eobjects.structuralfeatures.EObjectReferenceValueCondition;
import org.eclipse.emf.query.statements.FROM;
import org.eclipse.emf.query.statements.SELECT;
import org.eclipse.emf.query.statements.WHERE;
import org.eclipse.emf.transaction.Transaction;
import org.eclipse.emf.transaction.TransactionalEditingDomain;
import org.eclipse.emf.workspace.AbstractEMFOperation;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.commands.Command;
import org.eclipse.gmf.runtime.common.core.util.StringStatics;
import org.eclipse.gmf.runtime.diagram.ui.commands.ICommandProxy;
import org.eclipse.gmf.runtime.diagram.ui.editparts.ConnectionNodeEditPart;
import org.eclipse.gmf.runtime.diagram.ui.editparts.IGraphicalEditPart;
import org.eclipse.gmf.runtime.diagram.ui.parts.DiagramGraphicalViewer;
import org.eclipse.gmf.runtime.diagram.ui.util.EditPartUtil;
import org.eclipse.gmf.runtime.draw2d.ui.figures.PolylineConnectionEx;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.swt.SWT;

import de.mdelab.expressiondialogs.edit.commands.UpdateMergedLinkDeferredCommand;
import de.mdelab.expressiondialogs.figures.CrossFigure;
import de.mdelab.expressiondialogs.figures.ILineIsHideableFigure;
import de.mdelab.expressiondialogs.figures.MlstorypatternsDiagramConstants;
import de.mdelab.mlcore.MLNamedElement;
import de.mdelab.mlsdm.Activity;
import de.mdelab.mlsdm.ActivityEdgeGuardEnum;
import de.mdelab.mlstorypatterns.MatchTypeEnum;
import de.mdelab.mlstorypatterns.ModifierEnum;
import de.mdelab.mlstorypatterns.StoryPatternElement;

public class Utility {
	
	public static Comparator<EObject> eObjectClassComparator = new Comparator<EObject>() {
		
		@Override
		public int compare(EObject arg0, EObject arg1) {
			EClass eClass0 = (EClass) arg0, eClass1 = (EClass) arg1;
			return eClass0.getName().compareTo(eClass1.getName());
		}
	};

	public static Collection<EObject> getConcreteSubclasses(	final EClass p_superClass,
																final Collection<EPackage> p_searchedPackages ) {
		// SELECT * FROM StoryDiagramEcorePackage WHERE
		// abstract == false AND
		// interface == false AND
		// eAllSuperTypes.contains(superClass)

		EObjectCondition _1stCond = new EObjectAttributeValueCondition(EcorePackage.eINSTANCE.getEClass_Abstract(), new BooleanCondition(
				false));
		EObjectCondition _2ndCond = new EObjectAttributeValueCondition(EcorePackage.eINSTANCE.getEClass_Interface(), new BooleanCondition(
				false));
		EObjectCondition _3rdCond = new EObjectReferenceValueCondition(EcorePackage.eINSTANCE.getEClass_EAllSuperTypes(),
				new EObjectInstanceCondition( p_superClass ) );
		SELECT statement = new SELECT( new FROM( p_searchedPackages ), new WHERE(_1stCond.AND(_2ndCond).AND(_3rdCond)));
		
		final List<EObject> list = new ArrayList<EObject>(statement.execute());
		
		Collections.sort( list, eObjectClassComparator );
		
		return list;
	}


	public static String GuardEnum2String(ActivityEdgeGuardEnum guardEnum)
	{
		return guardEnum.toString().toLowerCase().replaceAll("_", " ");
	}

	public static ActivityEdgeGuardEnum String2GuardEnum(String text)
	{
		return ActivityEdgeGuardEnum.valueOf(text.replaceAll(" ", "_").toUpperCase());
	}

	public static String adaptStoryPatternElementModifierText(IGraphicalEditPart editPart)
	{
		StoryPatternElement spo = (StoryPatternElement) ((View) editPart.getModel()).getElement();

		switch (spo.getModifier())
		{
			case CREATE:
			{
				return "<<create>>";
			}
			case DESTROY:
			{
				return "<<destroy>>";
			}
			default:
			{
				return "";
			}
		}

	}

	public static void adaptLineStyle(PolylineConnectionEx figure, MatchTypeEnum spMatch)
	{
		for (Object o : figure.getChildren())
		{
			if (o instanceof CrossFigure)
			{
				figure.getChildren().remove(o);
				break;
			}
		}

		switch (spMatch)
		{
		/*	case NONE:
			{
				figure.setLineStyle(SWT.LINE_SOLID);
				break;
			}*/
			case OPTIONAL:
			{
				figure.setLineStyle(SWT.LINE_CUSTOM);
				figure.setLineDash(new int[]
				{
						15, 10
				});
				break;
			}
	/*		case NEGATIVE:
			{
				CrossFigure crossFigure = new CrossFigure();

				Dimension size = new Dimension(20, 20);
				crossFigure.setMinimumSize(size);
				crossFigure.setMaximumSize(size);
				crossFigure.setPreferredSize(size);

				figure.add(crossFigure, new ConnectionLocator(figure, ConnectionLocator.MIDDLE));
			}*/
			default:
			{
				figure.setLineStyle(SWT.LINE_SOLID);
				break;
			}
		}

	}

	public static void adaptColor(IFigure figure, ModifierEnum spMod)
	{
		// StoryPatternModifierEnumeration spMod = ((StoryPatternElement)
		// ((View) graphEditPart.getModel()).getElement()).getModifier();

		switch (spMod)
		{
			case CREATE:
			{
				figure.setForegroundColor(MlstorypatternsDiagramConstants.MODIFIER_CREATE_COLOR);
				break;
			}
			case DESTROY:
			{
				figure.setForegroundColor(MlstorypatternsDiagramConstants.MODIFIER_DESTROY_COLOR);
				break;
			}
			case NONE:
			{
				figure.setForegroundColor(MlstorypatternsDiagramConstants.MODIFIER_NONE_COLOR);
				break;
			}
			default:
			{
				figure.setForegroundColor(MlstorypatternsDiagramConstants.MODIFIER_NONE_COLOR);
				break;
			}
		}
	}

	/**
	 * Zum größten Teil kopiert aus
	 * org.eclipse.emf.ecoretools.diagram.edit.parts
	 * .EReferenceUtils.trackReferences
	 */
	public static void trackMergedLinks(ConnectionNodeEditPart linkEditPart, EObject opLink, boolean trackFully)
	{
		EditPart targetPart = linkEditPart.getTarget();
		if (!(targetPart instanceof IGraphicalEditPart))
		{
			return;
		}
		ConnectionNodeEditPart oppositeEditPart = null;
		for (Object part : ((IGraphicalEditPart) targetPart).getSourceConnections())
		{
			if (!(part instanceof ConnectionNodeEditPart))
			{
				continue;
			}
			if (((ConnectionNodeEditPart) part).resolveSemanticElement() == opLink) // ((StoryPatternLink)
																					// semanticElement).getOppositeStoryPatternLink()
			{
				oppositeEditPart = (ConnectionNodeEditPart) part;
				break;
			}
		}
		if (oppositeEditPart == null)
		{
			return;
		}
		// Hide line of the non selected reference
		ConnectionNodeEditPart masterPart;
		ConnectionNodeEditPart slavePart;
		if (oppositeEditPart.getSelected() != EditPart.SELECTED_NONE)
		{
			((ILineIsHideableFigure) linkEditPart.getFigure()).setHideLine(true);
			((ILineIsHideableFigure) oppositeEditPart.getFigure()).setHideLine(false);
			masterPart = oppositeEditPart;
			slavePart = linkEditPart;
		}
		else
		{
			((ILineIsHideableFigure) oppositeEditPart.getFigure()).setHideLine(true);
			((ILineIsHideableFigure) linkEditPart.getFigure()).setHideLine(false);
			masterPart = linkEditPart;
			slavePart = oppositeEditPart;
		}

		if (trackFully)
		{
			TransactionalEditingDomain editingDomain = masterPart.getEditingDomain();
			Command cmd = new ICommandProxy(new UpdateMergedLinkDeferredCommand(editingDomain, masterPart, slavePart));
			executeCommand(cmd, masterPart);
		}
	}

	/**
	 * Executes the supplied command inside an <code>unchecked action</code>
	 * Taken from the CanonicalEditPolicy class
	 * 
	 * @param cmd
	 *            command that can be executed (i.e., cmd.canExecute() == true)
	 * @param part
	 * 
	 * DB: Copied from Ecore tools during migration to Eclipse Luna
	 */
	public static void executeCommand(final Command cmd, IGraphicalEditPart part) {
		Map<String, Boolean> options = null;
		boolean isActivating = true;
		// use the viewer to determine if we are still initializing the diagram
		// do not use the DiagramEditPart.isActivating since
		// ConnectionEditPart's parent will not be a diagram edit part
		EditPartViewer viewer = part.getViewer();
		if (viewer instanceof DiagramGraphicalViewer) {
			isActivating = ((DiagramGraphicalViewer) viewer).isInitializing();
		}

		if (isActivating || !EditPartUtil.isWriteTransactionInProgress(part, false, false))
			options = Collections.singletonMap(Transaction.OPTION_UNPROTECTED, Boolean.TRUE);

		AbstractEMFOperation operation = new AbstractEMFOperation((part).getEditingDomain(), StringStatics.BLANK, options) {

			@Override
			protected IStatus doExecute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {

				cmd.execute();

				return Status.OK_STATUS;
			}
		};
		
		try {
			operation.execute(new NullProgressMonitor(), null);
		}
		catch ( final ExecutionException p_ex ) {
			// FIXME
			p_ex.printStackTrace();
			//EcoreDiagramEditorPlugin.getInstance().logError(Messages.EReferenceUtils_CanNotExecute, e);
		}
	}

	public static String getSpecificationString(EOperation specification)
	{
		String text = "";
		if (specification != null && specification.getEContainingClass() != null
				&& specification.getEContainingClass().getEPackage() != null)
		{
			/*
			 * Operation name
			 */
			text = specification.getEContainingClass().getName() + "." + specification.getName();

			/*
			 * Parameters
			 */
			text += "(";

			if (!specification.getEParameters().isEmpty())
			{
				for (EParameter parameter : specification.getEParameters())
				{
					text += parameter.getEType().getName() + " " + parameter.getName() + ", ";
				}

				text = text.substring(0, text.length() - 2);
			}
			text += ")";

			/*
			 * Return value
			 */
			if (specification.getEType() != null)
			{
				text += ":" + specification.getEType().getName();
			}
		}
		else
		{
			text = "";
		}

		return text;
	}

	/**
	 * DB: Issue #1802 Generalized parameter to EObject
	 * @param nElem
	 * @return
	 */
	public static String getFilterId( EObject nElem ) {
		return nElem.eClass().getName() + ": ";
	}

	/**
	 * Returns the activity that contains this element.
	 * 
	 * @param storyPatternLink
	 * @return
	 */
	public static Activity getActivity(MLNamedElement element)
	{
		do
		{
			element = (MLNamedElement) element.eContainer();
		}
		while (element != null && !(element instanceof Activity));

		return (Activity) element;
	}
}
