package de.mdelab.expressiondialogs.actions;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.ecore.EcorePackage;
import org.eclipse.gmf.runtime.common.core.command.CommandResult;
import org.eclipse.gmf.runtime.emf.commands.core.command.AbstractTransactionalCommand;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.window.Window;

import de.mdelab.expressiondialogs.MlsdmEditExpressionDialog;
import de.mdelab.expressiondialogs.Utility;
import de.mdelab.mlexpressions.MLStringExpression;
import de.mdelab.mlexpressions.MlexpressionsFactory;
import de.mdelab.mlsdm.ActivityEdge;
import de.mdelab.mlsdm.ActivityEdgeGuardEnum;
import de.mdelab.mlsdm.MlsdmPackage;
import de.mdelab.mlsdm.diagram.edit.parts.ActivityEdgeEditPart;

public class SetActivityEdgeGuardTypeAction extends CustomAbstractActionDelegate
{

	ActivityEdge			activityEdge;

	ActivityEdgeEditPart	activityEdgeEditPart;

	public void selectionChanged(IAction action, ISelection selection)
	{
		activityEdgeEditPart = null;
		activityEdge = null;
		if (selection instanceof IStructuredSelection)
		{
			IStructuredSelection structuredSelection = (IStructuredSelection) selection;
			if (structuredSelection.getFirstElement() instanceof ActivityEdgeEditPart)
			{
				activityEdgeEditPart = (ActivityEdgeEditPart) structuredSelection.getFirstElement();
				activityEdge = (ActivityEdge) activityEdgeEditPart.getPrimaryView().getElement();
			}
		}

		if (activityEdge != null)
		{
			if (Utility.GuardEnum2String(activityEdge.getGuardType()).equals(action.getText()))
			{
				action.setChecked(true);
			}
			else
			{
				action.setChecked(false);
			}
		}
	}

	@Override
	protected void doRun(IProgressMonitor progressMonitor)
	{

		final String actEdgeGuardValue = getAction().getText();

		AbstractTransactionalCommand command = new AbstractTransactionalCommand(activityEdgeEditPart.getEditingDomain(), "Set GuardType",
				null)
		{
			protected CommandResult doExecuteWithResult(IProgressMonitor monitor, IAdaptable info) throws ExecutionException
			{
				ActivityEdgeGuardEnum newGuard = Utility.String2GuardEnum(actEdgeGuardValue);
				
				if (newGuard != activityEdge.getGuardType())
				{
					activityEdge.setGuardType(newGuard);

					if (activityEdge.getGuardType() == ActivityEdgeGuardEnum.BOOLEAN)
					{
					//JOptionPane.showInputDialog(newGuard);
						MlsdmEditExpressionDialog editExpressionDialog = new MlsdmEditExpressionDialog(null);
						editExpressionDialog.setExpectedClassifier(EcorePackage.eINSTANCE.getEBoolean());
						editExpressionDialog.setExpressionOwner(activityEdge);
						if (activityEdge.getGuardExpression()==null)
						{
							MLStringExpression exp2 = null;
							exp2 = MlexpressionsFactory.eINSTANCE.createMLStringExpression();
							exp2.setExpressionLanguageID("OCL");
							activityEdge.setGuardExpression(exp2);
							editExpressionDialog.setExpression(exp2);
						}
						else
						{
							editExpressionDialog.setExpression(activityEdge.getGuardExpression());
						}
						editExpressionDialog.setStructuralFeature(MlsdmPackage.eINSTANCE.getActivityEdge_GuardExpression());

						if (editExpressionDialog.open() == Window.OK)
						{			

							activityEdge.setGuardExpression(editExpressionDialog.getExpression());
						}
						else
						{
							activityEdge.setGuardType(ActivityEdgeGuardEnum.NONE);
						}
					}
					else
					{
						activityEdge.setGuardExpression(null);
					}
				}

				return CommandResult.newOKCommandResult();
			}
		};

		execute(command);

	}
}
