/**
 */
package de.mdelab.mlsdm;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlcore.MLAnnotatedElement;
import de.mdelab.mlcore.MLElementWithUUID;
import de.mdelab.mlcore.MLNamedElement;
import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Semaphore</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A semaphore is used to control access to shared resources by concurrent threads. AcquireEdges take tokens from a Semaphore when the ActivityEdge of the AcquireEdge is executed. A ReleaseEdge does the opposite, i.e., when its ActivityEdge is executed, tokens are put back to the semaphore.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlsdm.Semaphore#getActivityNodeContainer <em>Activity Node Container</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.Semaphore#getTokenCount <em>Token Count</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.Semaphore#getAcquireEdges <em>Acquire Edges</em>}</li>
 *   <li>{@link de.mdelab.mlsdm.Semaphore#getReleaseEdges <em>Release Edges</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore()
 * @model annotation="http://www.eclipse.org/emf/2002/Ecore constraints='AcquireEdge'"
 * @generated
 */
public interface Semaphore extends MLElementWithUUID, MLAnnotatedElement, MLNamedElement {
	/**
	 * Returns the value of the '<em><b>Activity Node Container</b></em>' container reference.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.ActivityNodeContainer#getSemaphores <em>Semaphores</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Activity Node Container</em>' container
	 * reference isn't clear, there really should be more of a description
	 * here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Activity Node Container</em>' container reference.
	 * @see #setActivityNodeContainer(ActivityNodeContainer)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_ActivityNodeContainer()
	 * @see de.mdelab.mlsdm.ActivityNodeContainer#getSemaphores
	 * @model opposite="semaphores" resolveProxies="false" required="true" transient="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!Semaphore!activityNodeContainer'"
	 * @generated
	 */
	ActivityNodeContainer getActivityNodeContainer();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlsdm.Semaphore#getActivityNodeContainer
	 * <em>Activity Node Container</em>}' container reference. <!--
	 * begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Activity Node Container</em>'
	 *            container reference.
	 * @see #getActivityNodeContainer()
	 * @generated
	 */
	void setActivityNodeContainer(ActivityNodeContainer value);

	/**
	 * Returns the value of the '<em><b>Token Count</b></em>' attribute. The
	 * default value is <code>"1"</code>. <!-- begin-user-doc --> <!--
	 * end-user-doc --> <!-- begin-model-doc --> The number of tokens initially
	 * contained in this semaphore. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Token Count</em>' attribute.
	 * @see #setTokenCount(int)
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_TokenCount()
	 * @model default="1" required="true"
	 * @generated
	 */
	int getTokenCount();

	/**
	 * Sets the value of the '{@link de.mdelab.mlsdm.Semaphore#getTokenCount <em>Token Count</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Token Count</em>' attribute.
	 * @see #getTokenCount()
	 * @generated
	 */
	void setTokenCount(int value);

	/**
	 * Returns the value of the '<em><b>Acquire Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.AcquireEdge}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.AcquireEdge#getSemaphore <em>Semaphore</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Acquire Edges</em>' reference list isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Acquire Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_AcquireEdges()
	 * @see de.mdelab.mlsdm.AcquireEdge#getSemaphore
	 * @model opposite="semaphore" resolveProxies="false" required="true" ordered="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!Semaphore!acquireEdges'"
	 * @generated
	 */
	EList<AcquireEdge> getAcquireEdges();

	/**
	 * Returns the value of the '<em><b>Release Edges</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlsdm.ReleaseEdge}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlsdm.ReleaseEdge#getSemaphore <em>Semaphore</em>}'.
	 * <!-- begin-user-doc -->
	 * <p>
	 * If the meaning of the '<em>Release Edges</em>' reference list isn't
	 * clear, there really should be more of a description here...
	 * </p>
	 * <!-- end-user-doc -->
	 * @return the value of the '<em>Release Edges</em>' reference list.
	 * @see de.mdelab.mlsdm.MlsdmPackage#getSemaphore_ReleaseEdges()
	 * @see de.mdelab.mlsdm.ReleaseEdge#getSemaphore
	 * @model opposite="semaphore" resolveProxies="false" required="true" ordered="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlsdm/1.0!Semaphore!releaseEdges'"
	 * @generated
	 */
	EList<ReleaseEdge> getReleaseEdges();

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/Ecore/OCL/Pivot body='Tuple {\n\tmessage : String = \'Token count of semaphore \' + self.toString() + \' may not be negative.\',\n\tstatus : Boolean = \n\t\tif \tself.tokenCount &gt;= 0 then\n\t\t\ttrue\n\t\telse\n\t\t\tnull\n\t\tendif\n}.status'"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel body='final &lt;%java.lang.String%&gt; constraintName = \"Semaphore::TokenCountNotNegative\";\ntry {\n\t/**\n\t *\n\t * inv TokenCountNotNegative:\n\t *   let severity : Integer[1] = constraintName.getSeverity()\n\t *   in\n\t *     if severity &lt;= 0\n\t *     then true\n\t *     else\n\t *       let\n\t *         result : OclAny[1] = let\n\t *           status : Boolean[?] = if self.tokenCount &gt;= 0\n\t *           then true\n\t *           else null\n\t *           endif\n\t *         in\n\t *           if status = true\n\t *           then true\n\t *           else\n\t *             Tuple{message = \'Token count of semaphore \' +\n\t *               self.toString() + \' may not be negative.\', status = status\n\t *             }\n\t *           endif\n\t *       in\n\t *         constraintName.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n\t *     endif\n\t \052/\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.utilities.PivotUtil%&gt;.getExecutor(this, context);\n\t/*@Caught\052/ &lt;%java.lang.Object%&gt; CAUGHT_severity_0;\n\ttry {\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmPackage%&gt;.Literals.SEMAPHORE___TOKEN_COUNT_NOT_NEGATIVE__DIAGNOSTICCHAIN_MAP);\n\t\tCAUGHT_severity_0 = severity_0;\n\t}\n\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\tCAUGHT_severity_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t}\n\tif (CAUGHT_severity_0 instanceof &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;) {\n\t\tthrow (&lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;)CAUGHT_severity_0;\n\t}\n\tfinal /*@Thrown\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, CAUGHT_severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (le) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ int tokenCount = this.getTokenCount();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; BOXED_tokenCount = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.integerValueOf(tokenCount);\n\t\tfinal /*@NonInvalid\052/ boolean ge = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableGreaterThanEqualOperation%&gt;.INSTANCE.evaluate(executor, BOXED_tokenCount, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\t\tif (ge) {\n\t\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tstatus = null;\n\t\t}\n\t\tfinal /*@NonInvalid\052/ boolean eq = status == Boolean.TRUE;\n\t\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_1;\n\t\tif (eq) {\n\t\t\tsymbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_Token_32_count_32_of_32_semaphore_32, toString);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_may_32_not_32_be_32_negative);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\t\tsymbol_1 = symbol_0;\n\t\t}\n\t\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, constraintName, this, (Object)null, diagnostics, context, (Object)null, CAUGHT_severity_0, symbol_1, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t\tsymbol_2 = logDiagnostic;\n\t}\n\treturn Boolean.TRUE == symbol_2;\n}\ncatch (&lt;%java.lang.Throwable%&gt; e) {\n\treturn &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.validationFailedDiagnostic(constraintName, this, diagnostics, context, e);\n}'"
	 * @generated
	 */
	boolean TokenCountNotNegative(DiagnosticChain diagnostics, Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/Ecore/OCL/Pivot body='Tuple {\n\tmessage : String = \'Semaphore \' + self.toString() + \' must have at least one release edge.\',\n\tstatus : Boolean = \n\t\tif self.releaseEdges-&gt;size() &gt; 0 then\n\t\t\ttrue\n\t\telse\n\t\t\tnull\n\t\tendif\n}.status'"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel body='final &lt;%java.lang.String%&gt; constraintName = \"Semaphore::ReleaseEdge\";\ntry {\n\t/**\n\t *\n\t * inv ReleaseEdge:\n\t *   let severity : Integer[1] = constraintName.getSeverity()\n\t *   in\n\t *     if severity &lt;= 0\n\t *     then true\n\t *     else\n\t *       let\n\t *         result : OclAny[1] = let\n\t *           status : Boolean[?] = if self.releaseEdges-&gt;size() &gt; 0\n\t *           then true\n\t *           else null\n\t *           endif\n\t *         in\n\t *           if status = true\n\t *           then true\n\t *           else\n\t *             Tuple{message = \'Semaphore \' +\n\t *               self.toString() + \' must have at least one release edge.\', status = status\n\t *             }\n\t *           endif\n\t *       in\n\t *         constraintName.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n\t *     endif\n\t \052/\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.utilities.PivotUtil%&gt;.getExecutor(this, context);\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\n\t/*@Caught\052/ &lt;%java.lang.Object%&gt; CAUGHT_severity_0;\n\ttry {\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmPackage%&gt;.Literals.SEMAPHORE___RELEASE_EDGE__DIAGNOSTICCHAIN_MAP);\n\t\tCAUGHT_severity_0 = severity_0;\n\t}\n\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\tCAUGHT_severity_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t}\n\tif (CAUGHT_severity_0 instanceof &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;) {\n\t\tthrow (&lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;)CAUGHT_severity_0;\n\t}\n\tfinal /*@Thrown\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, CAUGHT_severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (le) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlsdm.ReleaseEdge%&gt;&gt; releaseEdges = this.getReleaseEdges();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_releaseEdges = idResolver.createSetOfAll(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.SET_CLSSid_ReleaseEdge, releaseEdges);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; size = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionSizeOperation%&gt;.INSTANCE.evaluate(BOXED_releaseEdges);\n\t\tfinal /*@NonInvalid\052/ boolean gt = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableGreaterThanOperation%&gt;.INSTANCE.evaluate(executor, size, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\t\tif (gt) {\n\t\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tstatus = null;\n\t\t}\n\t\tfinal /*@NonInvalid\052/ boolean eq = status == Boolean.TRUE;\n\t\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_1;\n\t\tif (eq) {\n\t\t\tsymbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_Semaphore_32, toString);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_must_32_have_32_at_32_least_32_one_32_release_32_edge);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\t\tsymbol_1 = symbol_0;\n\t\t}\n\t\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, constraintName, this, (Object)null, diagnostics, context, (Object)null, CAUGHT_severity_0, symbol_1, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t\tsymbol_2 = logDiagnostic;\n\t}\n\treturn Boolean.TRUE == symbol_2;\n}\ncatch (&lt;%java.lang.Throwable%&gt; e) {\n\treturn &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.validationFailedDiagnostic(constraintName, this, diagnostics, context, e);\n}'"
	 * @generated
	 */
	boolean ReleaseEdge(DiagnosticChain diagnostics, Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/Ecore/OCL/Pivot body='Tuple {\n\tmessage : String = \'Semaphore \' + self.toString() + \' must have at least one acquire edge.\',\n\tstatus : Boolean = \n\t\tif self.acquireEdges-&gt;size() &gt; 0 then\n\t\t\ttrue\n\t\telse\n\t\t\tnull\n\t\tendif\n}.status'"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel body='final &lt;%java.lang.String%&gt; constraintName = \"Semaphore::AcquireEdge\";\ntry {\n\t/**\n\t *\n\t * inv AcquireEdge:\n\t *   let severity : Integer[1] = constraintName.getSeverity()\n\t *   in\n\t *     if severity &lt;= 0\n\t *     then true\n\t *     else\n\t *       let\n\t *         result : OclAny[1] = let\n\t *           status : Boolean[?] = if self.acquireEdges-&gt;size() &gt; 0\n\t *           then true\n\t *           else null\n\t *           endif\n\t *         in\n\t *           if status = true\n\t *           then true\n\t *           else\n\t *             Tuple{message = \'Semaphore \' +\n\t *               self.toString() + \' must have at least one acquire edge.\', status = status\n\t *             }\n\t *           endif\n\t *       in\n\t *         constraintName.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n\t *     endif\n\t \052/\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.utilities.PivotUtil%&gt;.getExecutor(this, context);\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\n\t/*@Caught\052/ &lt;%java.lang.Object%&gt; CAUGHT_severity_0;\n\ttry {\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlsdm.MlsdmPackage%&gt;.Literals.SEMAPHORE___ACQUIRE_EDGE__DIAGNOSTICCHAIN_MAP);\n\t\tCAUGHT_severity_0 = severity_0;\n\t}\n\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\tCAUGHT_severity_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t}\n\tif (CAUGHT_severity_0 instanceof &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;) {\n\t\tthrow (&lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;)CAUGHT_severity_0;\n\t}\n\tfinal /*@Thrown\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, CAUGHT_severity_0, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (le) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlsdm.AcquireEdge%&gt;&gt; acquireEdges = this.getAcquireEdges();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_acquireEdges = idResolver.createSetOfAll(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.SET_CLSSid_AcquireEdge, acquireEdges);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; size = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionSizeOperation%&gt;.INSTANCE.evaluate(BOXED_acquireEdges);\n\t\tfinal /*@NonInvalid\052/ boolean gt = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableGreaterThanOperation%&gt;.INSTANCE.evaluate(executor, size, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\t\tif (gt) {\n\t\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tstatus = null;\n\t\t}\n\t\tfinal /*@NonInvalid\052/ boolean eq = status == Boolean.TRUE;\n\t\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_1;\n\t\tif (eq) {\n\t\t\tsymbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR_Semaphore_32, toString);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.STR__32_must_32_have_32_at_32_least_32_one_32_acquire_32_edge);\n\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.TUPLid_, sum_0, status);\n\t\t\tsymbol_1 = symbol_0;\n\t\t}\n\t\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, constraintName, this, (Object)null, diagnostics, context, (Object)null, CAUGHT_severity_0, symbol_1, &lt;%de.mdelab.mlsdm.MlsdmTables%&gt;.INT_0).booleanValue();\n\t\tsymbol_2 = logDiagnostic;\n\t}\n\treturn Boolean.TRUE == symbol_2;\n}\ncatch (&lt;%java.lang.Throwable%&gt; e) {\n\treturn &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.validationFailedDiagnostic(constraintName, this, diagnostics, context, e);\n}'"
	 * @generated
	 */
	boolean AcquireEdge(DiagnosticChain diagnostics, Map<Object, Object> context);

} // Semaphore
