package de.mdelab.mlsdm.diagram.custom.edit.parts;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.draw2d.PositionConstants;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.EMFEditPlugin;
import org.eclipse.emf.edit.provider.ComposedAdapterFactory;
import org.eclipse.emf.edit.provider.IItemLabelProvider;
import org.eclipse.gmf.runtime.draw2d.ui.figures.WrappingLabel;
import org.eclipse.gmf.runtime.notation.View;

import de.mdelab.expressiondialogs.Utility;
import de.mdelab.mlcallactions.CallAction;
import de.mdelab.mlcallactions.CallActionExpression;
import de.mdelab.mlcallactions.CallActionParameter;
import de.mdelab.mlexpressions.MLExpression;
import de.mdelab.mlsdm.ActivityFinalNode;
import de.mdelab.mlsdm.ActivityParameterDirectionEnum;
import de.mdelab.mlsdm.OutputParameterValue;
import de.mdelab.mlsdm.diagram.edit.parts.WrappingLabelEditPart;
import de.mdelab.mlstorypatterns.diagram.custom.edit.parts.IMLExpressionEditPart;

public class CustomActivityFinalNodeReturnValueLabelEditPart extends WrappingLabelEditPart implements IMLExpressionEditPart {

	public CustomActivityFinalNodeReturnValueLabelEditPart(View view)
	{
		super(view);
	}

	@Override
	protected void addNotationalListeners()
	{
		super.addNotationalListeners();
		EList<OutputParameterValue> exprs = ((ActivityFinalNode) ((View) getModel()).getElement()).getOutputParameterValues();
		for (OutputParameterValue e: exprs){
			MLExpression expr = e.getExpression();
			if (expr != null)
			{
				this.addListenerFilter(expr.eClass().getName(), this, expr);
		
				if (expr instanceof CallActionExpression)
				{
					TreeIterator<EObject> it = ((CallActionExpression) expr).eAllContents();
					for (EObject eObj; it.hasNext();)
					{
						eObj = it.next();

						// DB: Bug #1802
						this.addListenerFilter(Utility.getFilterId( eObj ), this, eObj);
					}
				}
			}
		}
		ActivityFinalNode finalNode = (ActivityFinalNode) ((View) getModel()).getElement();
		addListenerFilter("Activity", this, finalNode.getActivity());
		this.addListener();
	}
	private void addListener(){
		ActivityFinalNode finalNode = (ActivityFinalNode) ((View) getModel()).getElement();
		if (finalNode != null)
			for (int i = 0;i <finalNode.getActivity().getParameters().size();i++)
				addListenerFilter("Parameter" + i, this, (EObject) finalNode.getActivity().getParameters().toArray()[i]);
	}

	/*
	 * should be similar to handleNotificationEvent of:
	 * 
	 * CustomActivityEdgeGuardConstraintLabelEditPart
	 * CustomActivityFinalNodeReturnValueLabelEditPart
	 * CustomAttributeAssignmentEditPart CustomCallActionExpressionEditPart
	 * CustomCallActionExpression2EditPart CustomCallActionExpression3EditPart
	 * CustomStoryPatternExpressionLinkFeatureNameLabelEditPart
	 * CustomStoryPatternObjectClassifierLabelEditPart
	 */
	@Override
	protected void handleNotificationEvent(Notification event)
	{
		Object notifier = event.getNotifier();
		Object newValue = event.getNewValue();
		Object oldValue = event.getOldValue();
		int eventType = event.getEventType();

		if ((eventType == Notification.SET || eventType == Notification.ADD)
				&& (newValue instanceof CallAction || newValue instanceof MLExpression || newValue instanceof CallActionParameter))
		{
			// DB: Bug #1802
			this.addListenerFilter(Utility.getFilterId((EObject) newValue), this, (EObject) newValue);
			updateFigure();
		}
		else if (eventType == Notification.REMOVE
				&& (oldValue instanceof CallAction || oldValue instanceof MLExpression || oldValue instanceof CallActionParameter))
		{
			// DB: Bug #1802
			this.removeListenerFilter(Utility.getFilterId((EObject) oldValue));
			updateFigure();
		}
		else if (notifier instanceof ActivityFinalNode || notifier instanceof CallAction || notifier instanceof MLExpression
				|| notifier instanceof CallActionParameter)
		{
			updateFigure();
		}
		updateFigure();
		super.handleNotificationEvent(event);
	}

	protected void updateFigure()
	{
		((WrappingLabel) getFigure()).setTextWrap(true);
		((WrappingLabel) getFigure()).setTextJustification(PositionConstants.CENTER);

		StringBuilder labelBuilder = new StringBuilder();

		OutputParameterValue aParameter;
		String s = "";
		for (int i = 0; i<this.getOutParameters().size();i++){
			aParameter = this.getOutParameters().get(i);
			if (aParameter != null && aParameter.getParameter().getType() != null)
			{
				s = aParameter.getParameter().getType().getName();
				s = s + " " + this.getOutParameters().get(i).getParameter().getName();
				String text = "[null]";
				try{
					MLExpression expr = aParameter.getExpression();
					ComposedAdapterFactory factory = new ComposedAdapterFactory(EMFEditPlugin.getComposedAdapterFactoryDescriptorRegistry());
					text = ((IItemLabelProvider) factory.adapt(expr, IItemLabelProvider.class)).getText(expr);
				}
				catch (Exception e){
					e.printStackTrace();
				}
				s = s + " := " + text;

			}

			labelBuilder.append(s);//exp[i].getName()/*((ActivityFinalNode) ((View) getModel()).getElement()).getName()*/ + "-> " + exp[i].toString());
			if (i<this.getOutParameters().size()-1) labelBuilder.append(System.getProperty("line.separator"));
		}

		setLabelText(labelBuilder.toString());
	}
	
	private List<OutputParameterValue> getOutParameters() {
		final List<OutputParameterValue> resultParameters = new ArrayList<OutputParameterValue>();
		
		for ( final OutputParameterValue paramValue : ( (ActivityFinalNode) ( (View) getModel() ).getElement() ).getOutputParameterValues() ) {
			if ( paramValue.getParameter() != null && paramValue.getParameter().getDirection() != ActivityParameterDirectionEnum.IN ) {
				resultParameters.add( paramValue );
			}
		}
		
		return resultParameters;
	}

	@Override
	protected void refreshVisuals()
	{
		super.refreshVisuals();
		updateFigure();
	}

	@Override
	public MLExpression getMLExpression() {
		for ( final OutputParameterValue param : getOutParameters() ) {
			final MLExpression expression = param.getExpression();
			
			if ( expression != null ) {
				return expression;
			}
		}
		
		return null;
	}
}
