package de.mdelab.mlsdm.ui.popup.actions;

import java.util.Collections;

import org.eclipse.core.resources.WorkspaceJob;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.emf.ecore.util.EcoreUtil;

import de.mdelab.mlstorypatterns.StoryPattern;

public class ExtractStoryPatternsJob extends WorkspaceJob
{
	private static final String	PLUGIN_ID	= "de.mdelab.mlsdm.ui";
	private static final String	MLSP		= "mlsp";
	private URI					uri			= null;

	public ExtractStoryPatternsJob(final URI uri)
	{
		super("Extracting story patterns from '" + uri.toString() + "'...");
		this.uri = uri;
	}

	@Override
	public IStatus runInWorkspace(final IProgressMonitor monitor) throws CoreException
	{
		/*
		 * Load model
		 */
		try
		{
			final ResourceSet rs = new ResourceSetImpl();

			final Resource r = rs.getResource(this.uri, true);

			final TreeIterator<EObject> it = r.getAllContents();

			int counter = 0;

			while (it.hasNext())
			{
				final EObject eObject = it.next();

				if (eObject instanceof StoryPattern)
				{
					counter++;
					String suffix = String.valueOf(counter);

					if (((StoryPattern) eObject).getName() != null && !"".equals(((StoryPattern) eObject).getName()))
					{
						suffix += " - " + ((StoryPattern) eObject).getName();
					}

					final Resource r2 = rs.createResource(URI.createURI(this.uri.trimFileExtension().toString() + " - " + suffix)
							.appendFileExtension(ExtractStoryPatternsJob.MLSP));

					r2.getContents().add(EcoreUtil.copy(eObject));

					r2.save(Collections.EMPTY_MAP);
				}
			}
		}
		catch (final Exception e)
		{
			return new Status(IStatus.ERROR, ExtractStoryPatternsJob.PLUGIN_ID, "Exception occurred: " + e.getLocalizedMessage(), e);
		}

		return new Status(IStatus.OK, ExtractStoryPatternsJob.PLUGIN_ID, "");
	}
}
